@@ -409,6 +409,7 @@ class SeedHypervisorHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin,
     * Allocate IP addresses for all configured networks.
     * Add the host to SSH known hosts.
     * Configure a user account for use by kayobe for SSH access.
+    * Configure proxy settings.
     * Configure package repos.
     * Configure a PyPI mirror.
     * Optionally, create a virtualenv for remote target hosts.
@@ -441,17 +442,12 @@ class SeedHypervisorHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin,
         self.run_kayobe_playbooks(parsed_args, playbooks,
                                   limit="seed-hypervisor")
 
-        playbooks = _build_playbook_list(
-            "ssh-known-host", "kayobe-ansible-user",
-            "apt", "dnf", "pip", "kayobe-target-venv")
+        kwargs = {}
         if parsed_args.wipe_disks:
-            playbooks += _build_playbook_list("wipe-disks")
-        playbooks += _build_playbook_list(
-            "users", "dev-tools", "network", "firewall", "tuned", "sysctl",
-            "ip-routing", "snat", "time", "mdadm", "luks", "lvm",
-            "seed-hypervisor-libvirt-host")
+            kwargs["extra_vars"] = {"wipe_disks": True}
+        playbooks = _build_playbook_list("seed-hypervisor-host-configure")
         self.run_kayobe_playbooks(parsed_args, playbooks,
-                                  limit="seed-hypervisor")
+                                  limit="seed-hypervisor", **kwargs)
 
 
 class SeedHypervisorHostPackageUpdate(KayobeAnsibleMixin, VaultMixin, Command):
@@ -559,6 +555,7 @@ class SeedHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
     * Allocate IP addresses for all configured networks.
     * Add the host to SSH known hosts.
     * Configure a user account for use by kayobe for SSH access.
+    * Configure proxy settings.
     * Configure package repos.
     * Configure a PyPI mirror.
     * Optionally, create a virtualenv for remote target hosts.
@@ -598,17 +595,12 @@ class SeedHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
         self.run_kayobe_playbooks(parsed_args, playbooks, limit="seed")
 
         # Run kayobe playbooks.
-        playbooks = _build_playbook_list(
-            "ssh-known-host", "kayobe-ansible-user",
-            "apt", "dnf", "pip", "kayobe-target-venv")
+        kwargs = {}
         if parsed_args.wipe_disks:
-            playbooks += _build_playbook_list("wipe-disks")
-        playbooks += _build_playbook_list(
-            "users", "dev-tools", "disable-selinux", "network", "firewall",
-            "tuned", "sysctl", "ip-routing", "snat", "disable-glean", "time",
-            "mdadm", "luks", "lvm", "docker-devicemapper",
-            "kolla-ansible-user", "kolla-pip", "kolla-target-venv")
-        self.run_kayobe_playbooks(parsed_args, playbooks, limit="seed")
+            kwargs["extra_vars"] = {"wipe_disks": True}
+        playbooks = _build_playbook_list("seed-host-configure")
+        self.run_kayobe_playbooks(parsed_args, playbooks, limit="seed",
+                                  **kwargs)
 
         self.generate_kolla_ansible_config(parsed_args, service_config=False)
 
@@ -616,8 +608,7 @@ class SeedHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
         self.run_kolla_ansible_seed(parsed_args, "bootstrap-servers")
 
         # Run final kayobe playbooks.
-        playbooks = _build_playbook_list(
-            "kolla-host", "docker")
+        playbooks = _build_playbook_list("docker")
         self.run_kayobe_playbooks(parsed_args, playbooks, limit="seed")
 
         # Optionally, deploy a Docker Registry.
@@ -684,8 +675,7 @@ class SeedHostUpgrade(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
 
     def take_action(self, parsed_args):
         self.app.LOG.debug("Upgrading seed host services")
-        playbooks = _build_playbook_list(
-            "kayobe-target-venv", "kolla-target-venv")
+        playbooks = _build_playbook_list("seed-host-upgrade")
         self.run_kayobe_playbooks(parsed_args, playbooks, limit="seed")
 
 
@@ -870,6 +860,7 @@ class InfraVMHostConfigure(KayobeAnsibleMixin, VaultMixin,
     * Allocate IP addresses for all configured networks.
     * Add the host to SSH known hosts.
     * Configure a user account for use by kayobe for SSH access.
+    * Configure proxy settings.
     * Configure package repos.
     * Configure a PyPI mirror.
     * Optionally, create a virtualenv for remote target hosts.
@@ -904,16 +895,12 @@ class InfraVMHostConfigure(KayobeAnsibleMixin, VaultMixin,
         self.run_kayobe_playbooks(parsed_args, playbooks, limit="infra-vms")
 
         # Kayobe playbooks.
-        playbooks = _build_playbook_list(
-            "ssh-known-host", "kayobe-ansible-user",
-            "apt", "dnf", "pip", "kayobe-target-venv")
+        kwargs = {}
         if parsed_args.wipe_disks:
-            playbooks += _build_playbook_list("wipe-disks")
-        playbooks += _build_playbook_list(
-            "users", "dev-tools", "disable-selinux", "network", "firewall",
-            "tuned", "sysctl", "disable-glean", "disable-cloud-init", "time",
-            "mdadm", "luks", "lvm", "docker-devicemapper", "docker")
-        self.run_kayobe_playbooks(parsed_args, playbooks, limit="infra-vms")
+            kwargs["extra_vars"] = {"wipe_disks": True}
+        playbooks = _build_playbook_list("infra-vm-host-configure")
+        self.run_kayobe_playbooks(parsed_args, playbooks, limit="infra-vms",
+                                  **kwargs)
 
 
 class InfraVMHostPackageUpdate(KayobeAnsibleMixin, VaultMixin, Command):
@@ -1093,7 +1080,8 @@ class OvercloudDeprovision(KayobeAnsibleMixin, VaultMixin, Command):
 
     def take_action(self, parsed_args):
         self.app.LOG.debug("Deprovisioning overcloud")
-        playbooks = _build_playbook_list("overcloud-deprovision")
+        playbooks = _build_playbook_list("kolla-bifrost-hostvars",
+                                         "overcloud-deprovision")
         self.run_kayobe_playbooks(parsed_args, playbooks)
 
 
@@ -1120,6 +1108,7 @@ class OvercloudHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
     * Allocate IP addresses for all configured networks.
     * Add the host to SSH known hosts.
     * Configure a user account for use by kayobe for SSH access.
+    * Configure proxy settings.
     * Configure package repos.
     * Configure a PyPI mirror.
     * Optionally, create a virtualenv for remote target hosts.
@@ -1138,6 +1127,7 @@ class OvercloudHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
     * Optionally, create a virtualenv for kolla-ansible.
     * Configure a user account for kolla-ansible.
     * Configure Docker engine.
+    * Configure libvirt.
     """
 
     def get_parser(self, prog_name):
@@ -1157,17 +1147,12 @@ class OvercloudHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
         self.run_kayobe_playbooks(parsed_args, playbooks, limit="overcloud")
 
         # Kayobe playbooks.
-        playbooks = _build_playbook_list(
-            "ssh-known-host", "kayobe-ansible-user",
-            "apt", "dnf", "pip", "kayobe-target-venv")
+        kwargs = {}
         if parsed_args.wipe_disks:
-            playbooks += _build_playbook_list("wipe-disks")
-        playbooks += _build_playbook_list(
-            "users", "dev-tools", "disable-selinux", "network", "firewall",
-            "tuned", "sysctl", "disable-glean", "disable-cloud-init", "time",
-            "mdadm", "luks", "lvm", "docker-devicemapper",
-            "kolla-ansible-user", "kolla-pip", "kolla-target-venv")
-        self.run_kayobe_playbooks(parsed_args, playbooks, limit="overcloud")
+            kwargs["extra_vars"] = {"wipe_disks": True}
+        playbooks = _build_playbook_list("overcloud-host-configure")
+        self.run_kayobe_playbooks(parsed_args, playbooks, limit="overcloud",
+                                  **kwargs)
 
         self.generate_kolla_ansible_config(parsed_args, service_config=False)
 
@@ -1176,7 +1161,7 @@ class OvercloudHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
 
         # Further kayobe playbooks.
         playbooks = _build_playbook_list(
-            "kolla-host", "docker", "swift-block-devices")
+            "docker", "swift-block-devices", "compute-libvirt-host")
         self.run_kayobe_playbooks(parsed_args, playbooks, limit="overcloud")
 
 
@@ -1237,18 +1222,7 @@ class OvercloudHostUpgrade(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
 
     def take_action(self, parsed_args):
         self.app.LOG.debug("Upgrading overcloud host services")
-        playbooks = _build_playbook_list(
-            "kayobe-target-venv", "kolla-target-venv",
-            "overcloud-docker-sdk-upgrade", "overcloud-etc-hosts-fixup")
-        self.run_kayobe_playbooks(parsed_args, playbooks, limit="overcloud")
-
-        # TODO(mgoddard): Remove this in Y cycle after Kolla Ansible chrony
-        # container has been dropped for a cycle.
-        # NOTE(mgoddard): Clean up the chrony container if it exists, and
-        # deploy a host chrony daemon.
-        self.generate_kolla_ansible_config(parsed_args, service_config=False)
-        self.run_kolla_ansible_overcloud(parsed_args, "chrony-cleanup")
-        playbooks = _build_playbook_list("time")
+        playbooks = _build_playbook_list("overcloud-host-upgrade")
         self.run_kayobe_playbooks(parsed_args, playbooks, limit="overcloud")
 
 
@@ -1772,6 +1746,31 @@ class OvercloudDeploymentImageBuild(KayobeAnsibleMixin, VaultMixin, Command):
                                   extra_vars=extra_vars)
 
 
+class OvercloudHostImageBuild(KayobeAnsibleMixin, VaultMixin, Command):
+    """Build overcloud host disk images.
+
+    Builds host disk images using Diskimage Builder (DIB) for use when
+    provisioning the overcloud hosts.
+    """
+
+    def get_parser(self, prog_name):
+        parser = super(OvercloudHostImageBuild, self).get_parser(
+            prog_name)
+        group = parser.add_argument_group("Host Image Build")
+        group.add_argument("--force-rebuild", action="store_true",
+                           help="whether to force rebuilding the images")
+        return parser
+
+    def take_action(self, parsed_args):
+        self.app.LOG.debug("Building overcloud host disk images")
+        playbooks = _build_playbook_list("overcloud-host-image-build")
+        extra_vars = {}
+        if parsed_args.force_rebuild:
+            extra_vars["overcloud_host_image_force_rebuild"] = True
+        self.run_kayobe_playbooks(parsed_args, playbooks,
+                                  extra_vars=extra_vars)
+
+
 class OvercloudPostConfigure(KayobeAnsibleMixin, VaultMixin, Command):
     """Perform post-deployment configuration.
 
