@@ -49,7 +49,10 @@ def _get_veth_interface(context, bridge, inventory_hostname):
                                inventory_hostname)
     suffix = utils.get_hostvar(context, 'network_patch_suffix_phy',
                                inventory_hostname)
-    return prefix + bridge + suffix
+
+    # interface names can't be longer than 15 characters
+    char_limit = 15 - len(prefix) - len(suffix)
+    return prefix + bridge[:char_limit] + suffix
 
 
 def _get_veth_peer(context, bridge, inventory_hostname):
@@ -64,7 +67,10 @@ def _get_veth_peer(context, bridge, inventory_hostname):
                                inventory_hostname)
     suffix = utils.get_hostvar(context, 'network_patch_suffix_ovs',
                                inventory_hostname)
-    return prefix + bridge + suffix
+
+    # interface names can't be longer than 15 characters
+    char_limit = 15 - len(prefix) - len(suffix)
+    return prefix + bridge[:char_limit] + suffix
 
 
 def get_ovs_veths(context, names, inventory_hostname):
@@ -268,6 +274,36 @@ def net_mtu(context, name, inventory_hostname=None):
     return mtu
 
 
+@jinja2.pass_context
+def net_bridge_stp(context, name, inventory_hostname=None):
+    """Return the Spanning Tree Protocol (STP) state for a bridge.
+
+    On RL9 if STP is not defined, default it to 'false' to preserve
+    compatibility with network scripts. STP is 'true' in NetworkManager
+    by default, so we set it to 'false' here.
+
+    :param context: Jinja2 Context object.
+    :param name: The name of the network.
+    :param inventory_hostname: Ansible inventory hostname.
+    :returns: A string "true" or "false" representing the STP state.
+    """
+    bridge_stp = net_attr(context, name, 'bridge_stp', inventory_hostname)
+    os_family = context['ansible_facts']['os_family']
+    os_version = context['ansible_facts']['distribution_major_version']
+
+    if os_family == 'RedHat' and os_version == '8':
+        return None
+
+    if bridge_stp is None:
+        if os_family == 'RedHat' and os_version == '9':
+            return 'false'
+        else:
+            return None
+
+    bridge_stp = str(utils.call_bool_filter(context, bridge_stp)).lower()
+    return bridge_stp
+
+
 net_routes = _make_attr_filter('routes')
 net_rules = _make_attr_filter('rules')
 net_physical_network = _make_attr_filter('physical_network')
@@ -290,7 +326,11 @@ def net_libvirt_network_name(context, name, inventory_hostname=None):
 
 @jinja2.pass_context
 def net_bridge_ports(context, name, inventory_hostname=None):
-    return net_attr(context, name, 'bridge_ports', inventory_hostname)
+    ports = net_attr(context, name, 'bridge_ports', inventory_hostname)
+    if ports and not isinstance(ports, list):
+        raise errors.AnsibleFilterError("Bridge ports for network '%s' should"
+                                        " be a list", name)
+    return ports
 
 
 net_bond_mode = _make_attr_filter('bond_mode')
@@ -340,7 +380,7 @@ def _validate_rules(rules):
 
 
 @jinja2.pass_context
-def net_interface_obj(context, name, inventory_hostname=None):
+def net_interface_obj(context, name, inventory_hostname=None, names=None):
     """Return a dict representation of a network interface.
 
     The returned dict is compatible with the interfaces_ether_interfaces
@@ -360,6 +400,27 @@ def net_interface_obj(context, name, inventory_hostname=None):
         netmask = None
     vlan = net_vlan(context, name, inventory_hostname)
     mtu = net_mtu(context, name, inventory_hostname)
+
+    # NOTE(priteau): do not pass MTU for VLAN interfaces on bridges when it is
+    # identical to the parent bridge, to work around a NetworkManager bug.
+    if names is not None and net_is_vlan_interface(context, name,
+                                                   inventory_hostname):
+        # Make a mapping of bridge interfaces and their MTUs
+        bridge_mtus = {}
+        for bridge in net_select_bridges(context, names, inventory_hostname):
+            bridge_interface = net_interface(context, bridge,
+                                             inventory_hostname)
+            bridge_mtus[bridge_interface] = net_mtu(context, bridge,
+                                                    inventory_hostname)
+
+        # Get parent and check for its MTU if it is a bridge
+        parent_or_device = get_vlan_parent(
+            context, name, device, vlan, inventory_hostname)
+        if parent_or_device in bridge_mtus:
+            parent_mtu = bridge_mtus[parent_or_device]
+            if mtu == parent_mtu:
+                mtu = None
+
     routes = net_routes(context, name, inventory_hostname)
     if routes:
         routes = [_route_obj(route) for route in routes]
@@ -421,6 +482,7 @@ def net_bridge_obj(context, name, inventory_hostname=None):
     defroute = net_defroute(context, name, inventory_hostname)
     ethtool_opts = net_ethtool_opts(context, name, inventory_hostname)
     zone = net_zone(context, name, inventory_hostname)
+    stp = net_bridge_stp(context, name, inventory_hostname)
     vip_address = net_vip_address(context, name, inventory_hostname)
     allowed_addresses = [vip_address] if vip_address else None
     _validate_rules(rules)
@@ -440,6 +502,7 @@ def net_bridge_obj(context, name, inventory_hostname=None):
         'zone': zone,
         'allowed_addresses': allowed_addresses,
         'onboot': 'yes',
+        'stp': stp,
     }
     interface = {k: v for k, v in interface.items() if v is not None}
     return interface
@@ -724,6 +787,7 @@ def get_filters():
         'net_defroute': net_defroute,
         'net_ethtool_opts': net_ethtool_opts,
         'net_zone': net_zone,
+        'net_bridge_stp': net_bridge_stp,
         'net_interface_obj': net_interface_obj,
         'net_bridge_obj': net_bridge_obj,
         'net_bond_obj': net_bond_obj,
