@@ -20,17 +20,22 @@ import jinja2
 from kayobe.plugins.action import kolla_ansible_host_vars
 
 
-@jinja2.contextfilter
+@jinja2.pass_context
 def _net_interface(context, name):
     return context.get(name + '_interface')
 
 
-@jinja2.contextfilter
+@jinja2.pass_context
+def _net_parent(context, name):
+    return context.get(name + '_parent')
+
+
+@jinja2.pass_context
 def _net_vlan(context, name):
     return context.get(name + '_vlan')
 
 
-@jinja2.contextfilter
+@jinja2.pass_context
 def _net_select_bridges(context, names):
     return [name for name in names
             if (_net_interface(context, name) or "").startswith("br")]
@@ -42,6 +47,7 @@ class FakeTemplar(object):
         self.variables = variables
         self.env = jinja2.Environment()
         self.env.filters['net_interface'] = _net_interface
+        self.env.filters['net_parent'] = _net_parent
         self.env.filters['net_vlan'] = _net_vlan
         self.env.filters['net_select_bridges'] = _net_select_bridges
 
